# Interactive Reference

<!-- Display content from `astroautomata.com/pysr_interactive` -->

The following docs are interactive, and, based on your selections,
will create a snippet of Python code at the bottom which you can execute locally.
Clicking on each parameter's name will display a description.
Note that this is an incomplete list of options; for the full list,
see the [API Reference](api.md).

<embed src="https://astroautomata.com/pysr_interactive" width="100%" height="2000px" />
